# colorunittest
PyPi package for running and displaying a reformatted output of Python's unittest inside a Jupyter notebook.

## Installation
```pip install colorunittest```

## Description
To use, add the decorator `@run_unittest` to the unittest class and run the notebook cell.
![](https://github.com/HilarieSit/colorunittest/raw/master/example_pic.png)

Below is an example of the unittest output.
![](https://github.com/HilarieSit/colorunittest/raw/master/example_output.png)